@@ -1,5 +1,4 @@
-from dmoj.cli import commands
-from dmoj.commands.base_command import Command
+from dmoj.commands.base_command import Command, commands
 
 
 class HelpCommand(Command):
