@@ -1,15 +1,26 @@
 import os
 
-from .base_executor import ScriptExecutor
+from dmoj.executors.script_executor import ScriptExecutor
 
 
 class Executor(ScriptExecutor):
-    ext = '.coffee'
+    ext = 'coffee'
     name = 'COFFEE'
     nproc = -1
     command = 'node'
-    syscalls = ['newselect', 'select', 'pipe2', 'poll', 'write', 'epoll_create1',
-                'eventfd2', 'epoll_ctl', 'epoll_wait', 'sched_yield', 'setrlimit']
+    syscalls = [
+        'newselect',
+        'select',
+        'poll',
+        'epoll_create1',
+        'epoll_ctl',
+        'epoll_wait',
+        'epoll_pwait',
+        'sched_yield',
+        'setrlimit',
+        'eventfd2',
+        'statx',
+    ]
     test_program = '''\
 process.stdin.on 'readable', () ->
   chunk = process.stdin.read()
@@ -19,16 +30,16 @@ process.stdin.on 'readable', () ->
     address_grace = 1048576
 
     @classmethod
-    def initialize(cls, sandbox=True):
+    def initialize(cls):
         if 'coffee' not in cls.runtime_dict or not os.path.isfile(cls.runtime_dict['coffee']):
             return False
-        return super(Executor, cls).initialize(sandbox=sandbox)
+        return super().initialize()
 
     def get_cmdline(self):
         return [self.get_command(), self.runtime_dict['coffee'], self._code]
 
     def get_fs(self):
-        return super(Executor, self).get_fs() + [self.runtime_dict['coffee'], self._code]
+        return super().get_fs() + [self.runtime_dict['coffee'], self._code]
 
     @classmethod
     def get_versionable_commands(cls):
@@ -36,7 +47,4 @@ process.stdin.on 'readable', () ->
 
     @classmethod
     def get_find_first_mapping(cls):
-        return {
-            'node': ['nodejs', 'node'],
-            'coffee': ['coffee']
-        }
+        return {'node': ['nodejs', 'node'], 'coffee': ['coffee']}
