@@ -1,8 +1,8 @@
-from .base_executor import CompiledExecutor
+from dmoj.executors.compiled_executor import CompiledExecutor
 
 
 class Executor(CompiledExecutor):
-    ext = '.d'
+    ext = 'd'
     name = 'D'
     address_grace = 32768
     command = 'dmd'
@@ -13,6 +13,7 @@ void main() {
     writeln(readln());
 }
 '''
+    source_filename_format = 'main.{ext}'
 
     def get_compile_args(self):
         return [self.get_command(), '-O', '-inline', '-release', '-w', self._code, '-of%s' % self.problem]
