@@ -1,11 +1,12 @@
-from dmoj.executors.base_executor import CompiledExecutor
+from dmoj.executors.compiled_executor import CompiledExecutor
 from dmoj.executors.mixins import NullStdoutMixin
 
 
 class Executor(NullStdoutMixin, CompiledExecutor):
-    ext = '.hs'
+    ext = 'hs'
     name = 'HASK'
     command = 'ghc'
+    syscalls = ['poll']
     test_program = '''\
 main = do
     a <- getContents
@@ -13,4 +14,4 @@ main = do
 '''
 
     def get_compile_args(self):
-        return [self.get_command(), '-O', '-o', self.problem, self._code]
+        return [self.get_command(), '-O2', '-o', self.problem, self._code]
