@@ -1,8 +1,8 @@
-from .base_executor import CompiledExecutor
+from dmoj.executors.compiled_executor import CompiledExecutor
 
 
 class Executor(CompiledExecutor):
-    ext = '.i'
+    ext = 'i'
     name = 'ICK'
     command = 'ick'
     test_program = '''\
