@@ -8,9 +8,10 @@ with open(os.path.join(os.path.dirname(__file__), 'java-security.policy')) as po
 
 class Executor(JavaExecutor):
     name = 'KOTLIN'
-    ext = '.kt'
+    ext = 'kt'
 
     compiler = 'kotlinc'
+    compiler_time_limit = 20
     vm = 'kotlin_vm'
     security_policy = policy
 
@@ -21,11 +22,11 @@ fun main(args: Array<String>) {
 '''
 
     def create_files(self, problem_id, source_code, *args, **kwargs):
-        super(Executor, self).create_files(problem_id, source_code, *args, **kwargs)
+        super().create_files(problem_id, source_code, *args, **kwargs)
         self._jar_name = '%s.jar' % problem_id
 
     def get_cmdline(self):
-        res = super(Executor, self).get_cmdline()
+        res = super().get_cmdline()
         res[-2:] = ['-jar', self._jar_name]
         return res
 
@@ -35,3 +36,15 @@ fun main(args: Array<String>) {
     @classmethod
     def get_versionable_commands(cls):
         return [('kotlinc', cls.get_compiler()), ('java', cls.get_vm())]
+
+    @classmethod
+    def autoconfig(cls):
+        kotlinc = cls.find_command_from_list(['kotlinc'])
+        if kotlinc is None:
+            return None, False, 'Failed to find "kotlinc"'
+
+        java = cls.find_command_from_list(['java'])
+        if java is None:
+            return None, False, 'Failed to find "java"'
+
+        return cls.autoconfig_run_test({cls.compiler: kotlinc, cls.vm: cls.unravel_java(java)})
