@@ -2,10 +2,10 @@ from dmoj.executors.mono_executor import MonoExecutor
 
 
 class Executor(MonoExecutor):
-    ext = '.cs'
+    ext = 'cs'
     name = 'MONOCS'
     command = 'mono-csc'
-    command_paths = ['mono-csc', 'dmcs', 'mcs', 'gmcs']
+    command_paths = ['mono-csc', 'mcs', 'dmcs', 'gmcs']
 
     test_program = '''\
 using System;
