@@ -1,14 +1,15 @@
 import os
+from subprocess import CalledProcessError, check_output
+from typing import List
 
-from subprocess import check_output, CalledProcessError
-from .gcc_executor import GCCExecutor
 from dmoj.judgeenv import env
+from .gcc_executor import GCCExecutor
 
 
 class Executor(GCCExecutor):
-    ext = '.m'
-    objc_flags = []
-    objc_ldflags = []
+    ext = 'm'
+    objc_flags: List[str] = []
+    objc_ldflags: List[str] = []
     command = 'gobjc'
     name = 'OBJC'
     address_grace = 131072
@@ -27,16 +28,16 @@ int main (int argc, const char * argv[]) {
 '''
 
     def get_flags(self):
-        return self.objc_flags + super(Executor, self).get_flags()
+        return self.objc_flags + super().get_flags()
 
     def get_ldflags(self):
-        return self.objc_ldflags + super(Executor, self).get_ldflags()
+        return self.objc_ldflags + super().get_ldflags()
 
     def get_fs(self):
-        return super(Executor, self).get_fs() + ['/proc/\d+/cmdline$']
+        return super().get_fs() + [r'/proc/\d+/cmdline$']
 
     @classmethod
-    def initialize(cls, sandbox=True):
+    def initialize(cls):
         if 'gnustep-config' not in env['runtime'] or not os.path.isfile(env['runtime']['gnustep-config']):
             return False
         try:
@@ -44,4 +45,4 @@ int main (int argc, const char * argv[]) {
             cls.objc_ldflags = check_output([env['runtime']['gnustep-config'], '--base-libs']).split()
         except CalledProcessError:
             return False
-        return super(Executor, cls).initialize(sandbox=sandbox)
+        return super().initialize()
