@@ -1,8 +1,8 @@
-from .base_executor import ScriptExecutor
+from dmoj.executors.script_executor import ScriptExecutor
 
 
 class Executor(ScriptExecutor):
-    ext = '.pl'
+    ext = 'pl'
     name = 'PRO'
     command = 'swipl'
     test_program = '''
