@@ -1,8 +1,8 @@
-from .base_executor import ScriptExecutor
+from dmoj.executors.script_executor import ScriptExecutor
 
 
 class Executor(ScriptExecutor):
-    ext = '.js'
+    ext = 'js'
     name = 'V8JS'
     command = 'v8dmoj'
     test_program = 'print(gets());'
@@ -12,3 +12,6 @@ class Executor(ScriptExecutor):
     @classmethod
     def get_version_flags(cls, command):
         return [('-e', 'print(version())')]
+
+    def get_cmdline(self):
+        return [self.get_command(), '--stack-size=131072', self._code]  # 128MB Stack Limit
